@@ -17,6 +17,7 @@ module XMonad.Layout.DwmStyle
       -- $usage
       dwmStyle
     , Theme (..)
+    , def
     , defaultTheme
     , DwmStyle (..)
     , shrinkText, CustomShrink(CustomShrink)
@@ -36,8 +37,8 @@ import XMonad.Layout.Decoration
 -- Then edit your @layoutHook@ by adding the DwmStyle decoration to
 -- your layout:
 --
--- > myL = dwmStyle shrinkText defaultTheme (layoutHook defaultConfig)
--- > main = xmonad defaultConfig { layoutHook = myL }
+-- > myL = dwmStyle shrinkText def (layoutHook def)
+-- > main = xmonad def { layoutHook = myL }
 --
 -- For more detailed instructions on editing the layoutHook see:
 --
@@ -45,23 +46,21 @@ import XMonad.Layout.Decoration
 --
 -- You can also edit the default configuration options.
 --
--- > myDWConfig = defaultTheme { inactiveBorderColor = "red"
--- >                           , inactiveTextColor   = "red"}
+-- > myDWConfig = def { inactiveBorderColor = "red"
+-- >                  , inactiveTextColor   = "red"}
 --
 -- and
 --
--- > myL = dwmStyle shrinkText myDWConfig (layoutHook defaultConfig)
+-- > myL = dwmStyle shrinkText myDWConfig (layoutHook def)
 --
 -- A complete xmonad.hs file for this would therefore be:
 --
 -- > import XMonad
 -- > import XMonad.Layout.DwmStyle
 -- >
--- > main = xmonad defaultConfig {
--- >                    layoutHook =
--- >                        dwmStyle shrinkText defaultTheme
--- >                            (layoutHook defaultConfig)
--- >              }
+-- > main = xmonad def {
+-- >     layoutHook = dwmStyle shrinkText def (layoutHook def)
+-- >     }
 --
 
 
